summaryrefslogtreecommitdiff
path: root/src/modules/extra/m_ssl_gnutls.cpp
diff options
context:
space:
mode:
authorMatt Schatz <genius3000@g3k.solutions>2020-04-12 22:56:10 -0600
committerMatt Schatz <genius3000@g3k.solutions>2020-04-14 06:08:31 -0600
commitccebfe6e637b420bef05e8e0faf29bb19f1883d9 (patch)
tree7c2a3220343f7f4dd34eaf60bf77f5f1bda20638 /src/modules/extra/m_ssl_gnutls.cpp
parentc506023c5a0ba9abac4dad2d75115f71885dfc2f (diff)
Update user-facing text and comments of SSL to TLS.
Diffstat (limited to 'src/modules/extra/m_ssl_gnutls.cpp')
-rw-r--r--src/modules/extra/m_ssl_gnutls.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/modules/extra/m_ssl_gnutls.cpp b/src/modules/extra/m_ssl_gnutls.cpp
index 4d9216123..6cafcae22 100644
--- a/src/modules/extra/m_ssl_gnutls.cpp
+++ b/src/modules/extra/m_ssl_gnutls.cpp
@@ -907,7 +907,7 @@ info_done_dealloc:
}
CloseSession();
- sock->SetError("No SSL session");
+ sock->SetError("No TLS (SSL) session");
return -1;
}
@@ -1291,7 +1291,7 @@ class ModuleSSLGnuTLS : public Module
{
// First, store all profiles in a new, temporary container. If no problems occur, swap the two
// containers; this way if something goes wrong we can go back and continue using the current profiles,
// avoiding unpleasant situations where no new SSL connections are possible.
ProfileList newprofiles;
ConfigTagList tags = ServerInstance->Config->ConfTags("sslprofile");
@@ -1309,7 +1309,7 @@ class ModuleSSLGnuTLS : public Module
}
catch (CoreException& ex)
{
- throw ModuleException("Error while initializing the default SSL profile - " + ex.GetReason());
+ throw ModuleException("Error while initializing the default TLS (SSL) profile - " + ex.GetReason());
}
}
@@ -1334,7 +1334,7 @@ class ModuleSSLGnuTLS : public Module
}
catch (CoreException& ex)
{
- throw ModuleException("Error while initializing SSL profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
+ throw ModuleException("Error while initializing TLS (SSL) profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
}
newprofiles.push_back(prov);
@@ -1375,7 +1375,7 @@ class ModuleSSLGnuTLS : public Module
try
{
ReadProfiles();
- ServerInstance->SNO->WriteToSnoMask('a', "SSL module %s rehashed.", MODNAME);
+ ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module GnuTLS rehashed.");
}
catch (ModuleException& ex)
{
@@ -1396,9 +1396,9 @@ class ModuleSSLGnuTLS : public Module
if ((user) && (user->eh.GetModHook(this)))
{
- // User is using SSL, they're a local user, and they're using one of *our* SSL ports.
- // Potentially there could be multiple SSL modules loaded at once on different ports.
- ServerInstance->Users->QuitUser(user, "SSL module unloading");
+ // User is using TLS (SSL), they're a local user, and they're using one of *our* TLS (SSL) ports.
+ // Potentially there could be multiple TLS (SSL) modules loaded at once on different ports.
+ ServerInstance->Users->QuitUser(user, "GnuTLS module unloading");
}
}
}
@@ -1291,7 +1291,7 @@ class ModuleSSLGnuTLS : public Module
// First, store all profiles in a new, temporary container. If no problems occur, swap the two
// containers; this way if something goes wrong we can go back and continue using the current profiles,
- // avoiding unpleasant situations where no new SSL connections are possible.
+ // avoiding unpleasant situations where no new TLS (SSL) connections are possible.
ProfileList newprofiles;
ConfigTagList tags = ServerInstance->Config->ConfTags("sslprofile");